% Comparison between cleaned/non cleaned signal histograms
%
% Adaptive filtering techniques for the removal of noisy
% oscillatory transients from interferometric data
% E. Chassande-Mottin and S. V. Dhurandhar
%
% version: Tue Dec 14 15:02:26 MET 1999

clear

% GRAPHICS
printpath='./';
printok=1;

% HISTOGRAM WITH ORIGINAL SIGNAL
load step0

fobsmin=200; 
fobsmax=1500;
f=(1:xcol/2)/xcol*fs;
indexobs=find((f>fobsmin)&(f<fobsmax));
xf=fft(xorg2);
xff=zeros(xcol,1);
xff(indexobs)=xf(indexobs);
xobs0=ifft(xff);
xobs0(1:300)=zeros(300,1);
xobs0(end-299:end)=zeros(300,1);
[h1 p1]=hist(real(xobs0((200+5)*64-1:end-299)),50);

% HISTOGRAM WITH CLEANED SIGNAL
load step2

xf=fft(xoutput);
xff=zeros(xcol,1);
xff(indexobs)=xf(indexobs);
xobs2=ifft(xff);
xobs2(1:300)=zeros(300,1);
xobs2(end-299:end)=zeros(300,1);
[h2 p2]=hist(real(xobs2((200+5)*64-1:end-299)),50);

figure(1);
clf;
subplot(2,2,1); 
bar(p1,h1);
xlabel('data');
title('(a) input signal [200 Hz-1500 Hz]');

subplot(2,2,2); 
bar(p2,h2);
xlabel('data');
title('(b) output signal [200 Hz-1500 Hz]');

subplot(2,2,3); 
normplot(real(xobs0((200+5)*64-1:10:end-299)))
title('(c) distance to Gauss');
xlabel('data');
v=get(gca,'ytick');
set(gca,'ytick',v(1:2:end));

subplot(2,2,4); 
normplot(real(xobs2((200+5)*64-1:10:end-299)))
title('(d) distance to Gauss');
xlabel('data');
v=get(gca,'ytick');
set(gca,'ytick',v(1:2:end));

whitebg;

if printok,
  eval(['print -dps ' printpath 'rmhist.ps']);
end;