% Comparison between matched filter responses
%
% Adaptive filtering techniques for the removal of noisy
% oscillatory transients from interferometric data
% E. Chassande-Mottin and S. V. Dhurandhar
%
% version: Tue Dec 14 15:02:26 MET 1999

clear

% GRAPHICS
printpath='./';
printok=1;

% MATCHED FILTER WITH ORIGINAL SIGNAL
load step0

rcol=length(sref);
fobsmin=200; 
fobsmax=1300;
f=(0:xcol/2)/xcol*fs;
indexobs=find((f>fobsmin)&(f<fobsmax));

% spectrum estimation
px1=welch(xorg2(xcol/2+1:xcol),xcol,.5,window(xcol/2/4+1),fs);

% whitening
xf=fft(xorg2);
xff=zeros(xcol,1);
xff(indexobs)=xf(indexobs)./px1(indexobs);
xobs1=ifft(xff);

% remove border effects
xobs1(1:300)=zeros(300,1);
xobs1(end-299:end)=zeros(300,1);

% matched filter
[mf1 mfpos1]=mafi(xobs1,sref,1+xcol-deltab-deltae-(nout-rcol+1));

% scaling to amplitude and normalizing noise to unity
dtnorm=xcol/4;
mf1=sqrt(mf1);
noiserms1=mean(mf1(deltab+nout:deltab+nout+dtnorm));

% whitened output for figure
xfw=zeros(xcol,1);
xfw(indexobs)=xf(indexobs)./sqrt(px1(indexobs));
xw1=ifft(xfw);
xw1(1:300)=zeros(300,1);
xw1(end-299:end)=zeros(300,1);

% MATCHED FILTER WITH CLEAN SIGNAL

load step1

% spectrum estimation
px2=welch(xoutput2(xcol/2+1:xcol),xcol,.5,window(xcol/2/4+1),fs);

% whitening
xf=fft(xoutput2);
xff=zeros(xcol,1);
xff(indexobs)=xf(indexobs)./px2(indexobs);
xobs2=ifft(xff);

% ignore border effects
xobs2(1:300)=zeros(300,1);
xobs2(end-299:end)=zeros(300,1);

% matched filter
[mf2 mfpos2]=mafi(xobs2,sref,1+xcol-deltab-deltae-(nout-rcol+1));

% scaling to amplitude and normalizing noise to unity
dtnorm=xcol/4;
mf2=sqrt(mf2);
noiserms2=mean(mf2(deltab+nout:deltab+nout+dtnorm));

% whitened output for figure
xfw=zeros(xcol,1);
xfw(indexobs)=xf(indexobs)./sqrt(px2(indexobs));
xw2=ifft(xfw);
xw2(1:300)=zeros(300,1);
xw2(end-299:end)=zeros(300,1);

% DISPLAYS

figure(1);
clf;
deltat=4096;
t=((1:length(xobs1))-(deltab+nout))/fs;
index=32768-deltat:32768+deltat;
subplot(2,2,1); 
plot(t(index),real(xw1(index)));
axe=axis;
axis([t(index(1)) t(index(end)) axe(3) axe(4)]);
xlabel('time (s)');
title('(a)');

subplot(2,2,3); 
mfplot=mf1(index);
mfplot=mf1(index)./noiserms1;
plot(t(index),mfplot); 
hold on; 
%plot([t(mfpos1) t(mfpos1)],[0 1.1*max(mfplot)],'r--');
%plot([t(deltab+nout) t(deltab+nout)],[0 1.1*max(mfplot)],'g--');
hold off
axis([t(index(1)) t(index(end)) 0 1.1*max(mfplot)]);
xlabel('time (s)');
title('(c)');

subplot(2,2,2); 
plot(t(index),real(xw2(index)));
axis([t(index(1)) t(index(end)) axe(3) axe(4)]);
xlabel('time (s)');
title('(b)');

subplot(2,2,4); 
mfplot=mf2(index)./noiserms2;
plot(t(index),mfplot); 
hold on; 
%plot([t(mfpos2) t(mfpos2)],[0 1.1*max(mfplot)],'r--');
%plot([t(deltab+nout) t(deltab+nout)],[0 1.1*max(mfplot)],'g--');
hold off
axis([t(index(1)) t(index(end)) 0 max(mfplot)*1.1]);
xlabel('time (s)');
title('(d)');

if printok,
  eval(['print -dps ' printpath 'rmmafi.ps']);
end;