% Comparison between clean/non clean power spectra
% Adaptive filtering techniques for the removal of noisy
% oscillatory transients from interferometric data
%
% E. Chassande-Mottin and S. V. Dhurandhar
%
% version: Tue Dec 14 15:02:26 MET 1999

clear

% GRAPHICS
printpath='./';
printok=1;

% CONSTANTS
ARM_LENGTH94=38.25;

% POWER SPEC WITH ORIGINAL SIGNAL
load step0

fobsmin=200; 
fobsmax=1500;
f=(1:xcol/2)/xcol*fs;
indexobs=find((f>fobsmin)&(f<fobsmax));
xf=fft(xorg2);
xff=zeros(xcol,1);
xff(indexobs)=xf(indexobs);
xobs0=2*real(ifft(xff));
xobs0(1:300)=zeros(300,1);
xobs0(end-299:end)=zeros(300,1);

[px1 f]=welch(ARM_LENGTH94*xobs0(xcol/2+1:xcol),xcol,.5,window(xcol/2/4+1),fs);

% POWER SPEC WITH CLEAN SIGNAL
load step2

xf=fft(xoutput);
xff=zeros(xcol,1);
xff(indexobs)=xf(indexobs);
xobs2=2*real(ifft(xff));
xobs2(1:300)=zeros(300,1);
xobs2(end-299:end)=zeros(300,1);

[px2 f]=welch(ARM_LENGTH94*xobs2(xcol/2+1:xcol),xcol,.5,window(xcol/2/4+1),fs);

figure(1);
clf;
subplot(2,1,1); 
semilogy(f/1e3,sqrt(px1));
axis([0.3 1 1e-21 1e-16]);
xlabel('frequency [kHz]');
ylabel('sensitivity [m/Hz^{1/2}]');
title('(a) input signal [300 Hz-1 kHz]');
grid

subplot(2,1,2); 
semilogy(f/1e3,sqrt(px2));
axis([0.3 1 1e-21 1e-16]);
ylabel('sensitivity [m/Hz^{1/2}]');
xlabel('frequency [kHz]');
title('(b) output signal [300 Hz-1 kHz]');
grid;

if printok,
  eval(['print -dps ' printpath 'rmpspec.ps']);
end;
