% Signal loader
% Adaptive filtering techniques for the removal of noisy
% oscillatory transients from interferometric data
% E. Chassande-Mottin and S. V. Dhurandhar
%
% version: Wed Feb 23 19:05:38 MET 2000
% 
% To download the Caltech40 meter data set the GRASP_FRAMEPATH
% to the correct value before running matlab.

% setenv GRASP_FRAMEPATH /nfs/origin/data/eric/14nov94.2.frame

if exist('step1.mat');
  !\rm step0.mat
  !\rm step1.mat
  !\rm step2.mat
end;

clear
xcol=65536;

% --------------------------------------------------
% CALTECH 40 METER SIGNAL
% --------------------------------------------------

fmin=154; % filter the low frequency out
          % otherwise there are border effect
[xorg fgetoutput]=gr40mload(2*xcol,fmin); 
fs=fgetoutput.srate;

xorg1=xorg(1:xcol);
xorg2=xorg(xcol+1:2*xcol);
clear xorg;

figure(1);
clf;
subplot(2,1,1);
plot(xorg1);
title('data1');
subplot(2,1,2);
plot(xorg2);
title('data2');
pause;

% --------------------------------------------------
% FAKE INSPIRAL SIGNAL
% --------------------------------------------------

m1=1.4; m2=1.4; r=.02;
fisco=1/(6^(3/2)*pi*(m1+m2)*4.926e-6);
deltae=xcol/2; deltab=1024;
tin=(xcol-deltab-deltae)/fs;
[tout,t,s,sref,f,nout]=plchirp2(m1,m2,r,tin,fisco,fs);
fmin=200;
index=max(find(f(1:nout)<fmin));

% Template for the matched filter
sref=s(index:nout);

% Signal
s=s(end-(xcol-deltab-deltae)+1:end);
s=[zeros(deltab,1);s;zeros(deltae,1)];

figure(1);
clf;
subplot(2,1,1);
plot(s);
title('s');
subplot(2,1,2);
plot(sref);
title('sref');

% Caltech signal + fake signal
xorg2=xorg2+s;

save step0 xorg1 xorg2 s sref fs xcol deltab deltae nout