% Verification whether the inspiral chirp is still in the data
% after denoising
%
% Adaptive filtering techniques for the removal of noisy
% oscillatory transients from interferometric data
% E. Chassande-Mottin and S. V. Dhurandhar
%
% version: Tue Dec 14 15:02:26 MET 1999

% GRAPHICS
printpath='./';
printok=1;

% SIGNAL
load step0
load step2

[px2 f]=welch(xoutput(xcol/2+1:xcol),xcol,.5,window(xcol/2/4+1),fs);

fobsmin=200; 
fobsmax=1500;
indexobs=find((f>fobsmin)&(f<fobsmax));

% get a smoothed whitening filter (with a linear fit of the PS in a log-log plot)
% (we use this, otherwise the whiten ref. signal is not really nice and
% the figure is difficult to understand)

clf;
a0=3.1095e-31;alpha=-3.4898;
loglog(f(indexobs),px2(indexobs));
% [f1 a1]=ginput(1);
% [f2 a2]=ginput(1);
% alpha=(log(a1)-log(a2))/(log(f1)-log(f2))
% a0=exp(log(a1)-alpha*log(f1))
hold on
loglog(f(indexobs),a0*f(indexobs).^(alpha));
hold off;
pause;

% whiten signal and ref. signal
spect=a0*f(indexobs).^(alpha);
xf=fft(xoutput);
sf=fft(s);
xff=zeros(xcol,1);
sff=zeros(xcol,1);
xff(indexobs)=xf(indexobs)./sqrt(spect)';
sff(indexobs)=sf(indexobs)./sqrt(spect)';
xobs2=ifft(xff);
sobs=ifft(sff);
xobs2(1:300)=zeros(300,1);
xobs2(end-299:end)=zeros(300,1);

% DISPLAYS
t=(1:length(xobs2))/fs;

figure(1)
clf;
plot((-256:32)/fs,real(xobs2(xcol/2+(-256:32))));
hold on
h=plot((-256:32)/fs,real(sobs(xcol/2+(-256:32))));
set(h,'LineWidth',1.5);
hold off
axe=axis;
axemax=max(abs([axe(3) axe(4)]));
axis([-256/fs 32/fs -axemax axemax]);
grid on
xlabel('time (s)');
ylabel('whiten signal amplitude (no dim.)');

if printok
  eval(['print -dps ' printpath 'rmwaveform.ps']);
end;